==> splight-lib-2.0.18.tar.gz: splight-lib-2.0.18/splight_models/constants.py <==
# TODO remove this file
import logging
from enum import Enum, IntEnum


class SeverityType(str, Enum):
    system = 'system'
    info = 'info'
    low = 'low'
    medium = 'medium'
    high = 'high'
    critical = 'critical'


class ComponentSize(str, Enum):
    small = "small"
    medium = "medium"
    large = "large"
    very_large = "very_large"

    def __str__(self):
        return self.value


class LogginLevel(IntEnum):
    critical = logging.CRITICAL
    error = logging.ERROR
    warning = logging.WARNING
    info = logging.INFO
    debug = logging.DEBUG
    notset = logging.NOTSET

    def __str__(self):
        return str(self.value)

    @classmethod
    def _missing_(cls, value):
        return super()._missing_(int(value))


class RestartPolicy(str, Enum):
    ALWAYS = "Always"
    ON_FAILURE = "OnFailure"
    NEVER = "Never"


class DeploymentStatus(str, Enum):
    STOPPED = "Stopped"
    PENDING = "Pending"
    RUNNING = "Running"
    SUCCEEDED = "Succeeded"
    FAILED = "Failed"
    UNKNOWN = "Unknown"


class ComponentStatus(str, Enum):
    STOPPED = "Stopped"
    PENDING = "Pending"
    RUNNING = "Running"
    SUCCEEDED = "Succeeded"
    FAILED = "Failed"
    UNKNOWN = "Unknown"


class PrivacyPolicy(str, Enum):
    PUBLIC = "public"
    PRIVATE = "private"

    @classmethod
    def choices(cls):
        return [(key.value, key.name) for key in cls]


class VerificationLevel(str, Enum):
    VERIFIED = "verified"
    UNVERIFIED = "unverified"
    OFFICIAL = "official"

    @classmethod
    def choices(cls):
        return [(key.value, key.name) for key in cls]


class BuildStatus(str, Enum):
    PENDING = "pending"
    BUILDING = "building"
    FAILED = "failed"
    SUCCESS = "success"
    UNKNOWN = "unknown"

    @classmethod
    def choices(cls):
        return [(key.value, key.name) for key in cls]


class ComponentType(str, Enum):
    ALGORITHM = "algorithm"
    NETWORK = "network"
    CONNECTOR = "connector"
    SIMULATOR = "simulator"

    @classmethod
    def choices(cls):
        return [(key.value, key.name) for key in cls]

==> splight-lib-2.0.19.tar.gz: splight-lib-2.0.19/splight_models/constants.py <==
import logging
from enum import Enum, IntEnum


class ChoiceMixin(str, Enum):
    @classmethod
    def choices(cls):
        return [(key.value.lower(), key.name.capitalize()) for key in cls]


class SeverityType(str, Enum):
    system = 'system'
    info = 'info'
    low = 'low'
    medium = 'medium'
    high = 'high'
    critical = 'critical'


class ComponentSize(str, Enum):
    small = "small"
    medium = "medium"
    large = "large"
    very_large = "very_large"

    def __str__(self):
        return self.value


class LogginLevel(IntEnum):
    critical = logging.CRITICAL
    error = logging.ERROR
    warning = logging.WARNING
    info = logging.INFO
    debug = logging.DEBUG
    notset = logging.NOTSET

    def __str__(self):
        return str(self.value)

    @classmethod
    def _missing_(cls, value):
        return super()._missing_(int(value))


class RestartPolicy(str, Enum):
    ALWAYS = "Always"
    ON_FAILURE = "OnFailure"
    NEVER = "Never"


class DeploymentStatus(str, Enum):
    STOPPED = "Stopped"
    PENDING = "Pending"
    RUNNING = "Running"
    SUCCEEDED = "Succeeded"
    FAILED = "Failed"
    UNKNOWN = "Unknown"


class MinComponentCapacity(ChoiceMixin):
    SMALL = 'small'
    MEDIUM = 'medium'
    LARGE = 'large'
    VERY_LARGE = 'very_large'


class ComponentStatus(ChoiceMixin):
    STOPPED = "Stopped"
    PENDING = "Pending"
    RUNNING = "Running"
    SUCCEEDED = "Succeeded"
    FAILED = "Failed"
    UNKNOWN = "Unknown"


class PrivacyPolicy(ChoiceMixin):
    PUBLIC = "public"
    PRIVATE = "private"


class VerificationLevel(ChoiceMixin):
    VERIFIED = "verified"
    UNVERIFIED = "unverified"
    OFFICIAL = "official"


class BuildStatus(ChoiceMixin):
    PENDING = "pending"
    BUILDING = "building"
    FAILED = "failed"
    SUCCESS = "success"
    UNKNOWN = "unknown"


class ComponentType(ChoiceMixin):
    ALGORITHM = "algorithm"
    NETWORK = "network"
    CONNECTOR = "connector"
    SIMULATOR = "simulator"
